@@ -54,6 +54,7 @@ clearlooks_set_widget_parameters (const GtkWidget      *widget,
 	params->focus       = widget && GTK_WIDGET_HAS_FOCUS (widget);
 	params->is_default  = widget && GE_WIDGET_HAS_DEFAULT (widget);
 	params->enable_glow = FALSE;
+	params->radius      = CLEARLOOKS_STYLE (style)->radius;
 
 	if (!params->active && widget && GE_IS_TOGGLE_BUTTON (widget))
 		params->active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
@@ -61,8 +62,10 @@ clearlooks_set_widget_parameters (const GtkWidget      *widget,
 	params->xthickness = style->xthickness;
 	params->ythickness = style->ythickness;
 		
-	/* I want to avoid to have to do this. I need it for GtkEntry, unless I
-	   find out why it doesn't behave the way I expect it to. */
+	/* This is used in GtkEntry to fake transparency. The reason to do this
+	 * is that the entry has it's entire background filled with base[STATE].
+	 * This is not a very good solution as it will eg. fail if one changes
+	 * the background color of a notebook. */
 	params->parentbg = CLEARLOOKS_STYLE (style)->colors.bg[state_type];
 	clearlooks_get_parent_bg (widget, &params->parentbg);
 }
@@ -75,47 +78,23 @@ clearlooks_style_draw_flat_box (DRAW_ARGS)
 	    !strncmp ("cell_even", detail, 9) ||
 	    !strncmp ("cell_odd", detail, 8)))
 	{
+		WidgetParameters params;
 		ClearlooksStyle  *clearlooks_style;
 		ClearlooksColors *colors;
 		cairo_t          *cr;
 
-		cairo_pattern_t *pattern;
-		CairoColor       lower_color;
-		CairoColor       upper_color;
-
 		CHECK_ARGS
 		SANITIZE_SIZE
 
 		clearlooks_style = CLEARLOOKS_STYLE (style);
+		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 		colors = &clearlooks_style->colors;
 		cr = ge_gdk_drawable_to_cairo (window, area);
 
-		cairo_translate (cr, x, y);
+		/* XXX: We could expose the side details by setting params->corners accordingly
+		 *      or adding another option. */
+		STYLE_FUNCTION (draw_selected_cell) (cr, colors, &params, x, y, width, height);
 
-		if (widget && GTK_WIDGET_HAS_FOCUS (widget))
-		{
-			upper_color = colors->base[state_type];
-		}
-		else
-		{
-			upper_color = colors->base[GTK_STATE_ACTIVE];
-		}
-
-		ge_shade_color(&upper_color, 0.8, &lower_color);
-
-		pattern = cairo_pattern_create_linear (0, 0, 0, height);
-		cairo_pattern_add_color_stop_rgb (pattern, 0.0, upper_color.r,
-		                                                upper_color.g,
-		                                                upper_color.b);
-		cairo_pattern_add_color_stop_rgb (pattern, 1.0, lower_color.r,
-		                                                lower_color.g,
-		                                                lower_color.b);
-
-		cairo_set_source (cr, pattern);
-		cairo_rectangle  (cr, 0, 0, width, height);
-		cairo_fill       (cr);
-
-		cairo_pattern_destroy (pattern);
 		cairo_destroy (cr);
 	}
 	else if (CLEARLOOKS_STYLE (style)->style == CL_STYLE_GLOSSY &&
@@ -203,7 +182,7 @@ clearlooks_style_draw_shadow (DRAW_ARGS)
 		WidgetParameters params;
 		FrameParameters frame;
 
-		frame.shadow = CL_SHADOW_NONE;
+		frame.shadow = shadow_type;
 		frame.gap_x  = -1;
 		frame.border = &colors->shade[5];
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
@@ -236,7 +215,7 @@ clearlooks_style_draw_box_gap (DRAW_ARGS,
 		frame.gap_side  = gap_side;
 		frame.gap_x     = gap_x;
 		frame.gap_width = gap_width;
-		frame.border    = &colors->shade[6];
+		frame.border    = &colors->shade[5];
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 
@@ -251,8 +230,6 @@ clearlooks_style_draw_box_gap (DRAW_ARGS,
 	}
 	else
 	{
-		/* if (widget)
-			printf("box_gap: %s %s\n", detail, G_OBJECT_TYPE_NAME (widget)); */
 		clearlooks_parent_class->draw_box_gap (style, window, state_type, shadow_type,
 									   area, widget, detail,
 									   x, y, width, height,
@@ -300,7 +277,6 @@ clearlooks_style_draw_extension (DRAW_ARGS, GtkPositionType gap_side)
 	}
 	else
 	{
-		/* printf("draw_extension: %s\n", detail); */
 		clearlooks_parent_class->draw_extension (style, window, state_type, shadow_type, area,
 		                              widget, detail, x, y, width, height,
 		                              gap_side);
@@ -377,10 +353,6 @@ clearlooks_style_draw_handle (DRAW_ARGS, GtkOrientation orientation)
 		
 		STYLE_FUNCTION(draw_handle) (cr, colors, &params, &handle,
 		                        x, y, width, height);
-/*
-		clearlooks_parent_class->draw_handle (style, window, state_type, shadow_type, area,
-		                           widget, detail, x, y, width, height,
-		                           orientation);*/
 	}
 
 	cairo_destroy (cr);
@@ -396,12 +368,8 @@ clearlooks_style_draw_box (DRAW_ARGS)
 	cr     = ge_gdk_drawable_to_cairo (window, area);
 	colors = &clearlooks_style->colors;
 
-	if ((width == -1) && (height == -1))
-		gdk_window_get_size (window, &width, &height);
-	else if (width == -1)   
-		gdk_window_get_size (window, &width, NULL);
-	else if (height == -1)
-		gdk_window_get_size (window, NULL, &height);
+	CHECK_ARGS
+	SANITIZE_SIZE
 
 	if (DETAIL ("menubar") && !ge_is_panel_widget_item(widget))
 	{
@@ -418,7 +386,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 	else if (DETAIL ("button") && widget && widget->parent &&
                   (GE_IS_TREE_VIEW(widget->parent) ||
                    GE_IS_CLIST (widget->parent) ||
-                   ge_object_is_a (widget->parent, "ETree"))) /* ECanvas inside ETree */
+                   ge_object_is_a (G_OBJECT(widget->parent), "ETree"))) /* ECanvas inside ETree */
 	{
 		WidgetParameters params;
 		ListViewHeaderParameters header;
@@ -426,7 +394,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		gint columns, column_index;
 		gboolean resizable = TRUE;
 		
-		/* XXX: make unknown treeview header CL_ORDER_MIDDLE */
+		/* XXX: This makes unknown treeview header CL_ORDER_MIDDLE, in need for something nicer */
 		columns = 3;
 		column_index = 1;
 		
@@ -473,15 +441,6 @@ clearlooks_style_draw_box (DRAW_ARGS)
 			else
 				params.corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
 			
-			/* Seriously, why can't non-gtk-apps at least try to be decent citizens?
-			   Take this fscking OpenOffice.org 1.9 for example. The morons responsible
-			   for this utter piece of crap gave the clip size wrong values! :'(  */
-			   // Is this comment still necessary? ;) -dborg
-/*			cairo_reset_clip (cr);
-			cairo_rectangle (cr, x+ 0.5, y+ 0.5, 10, 10);
-			cairo_clip (cr);
-			cairo_new_path (cr);
-*/
 			shadow.shadow = CL_SHADOW_IN;
 
 			if (params.xthickness > 2)
@@ -599,7 +558,6 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		
 		scrollbar.horizontal = TRUE;
 		scrollbar.junction   = clearlooks_scrollbar_get_junction (widget);
-		scrollbar.steppers   = clearlooks_scrollbar_visible_steppers (widget);
 		
 		if (GE_IS_RANGE (widget))
 			scrollbar.horizontal = GTK_RANGE (widget)->orientation == GTK_ORIENTATION_HORIZONTAL;
@@ -664,18 +622,35 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		if (area)
 		{
 			GdkRectangle tmp = *area;
-			switch (progressbar.orientation)
+			if (!progressbar.pulsing)
 			{
-				case GTK_PROGRESS_RIGHT_TO_LEFT:
+				switch (progressbar.orientation)
+				{
+					case GTK_PROGRESS_RIGHT_TO_LEFT:
+						tmp.x -= 1;
+					case GTK_PROGRESS_LEFT_TO_RIGHT:
+						tmp.width += 1;
+						break;
+					case GTK_PROGRESS_BOTTOM_TO_TOP:
+						tmp.y -= 1;
+					case GTK_PROGRESS_TOP_TO_BOTTOM:
+						tmp.height += 1;
+						break;
+				}
+			}
+			else
+			{
+				if (progressbar.orientation == GTK_PROGRESS_RIGHT_TO_LEFT ||
+				    progressbar.orientation == GTK_PROGRESS_LEFT_TO_RIGHT)
+				{
 					tmp.x -= 1;
-				case GTK_PROGRESS_LEFT_TO_RIGHT:
-					tmp.width += 1;
-					break;
-				case GTK_PROGRESS_BOTTOM_TO_TOP:
+					tmp.width += 2;
+				}
+				else
+				{
 					tmp.y -= 1;
-				case GTK_PROGRESS_TOP_TO_BOTTOM:
-					tmp.height += 1;
-					break;
+					tmp.height += 2;
+				}
 			}
 			
 			cairo_reset_clip (cr);
@@ -687,22 +662,6 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		                                  x, y, width, height,
 		                                  10 - (int)(elapsed * 10.0) % 10);
 	}
-	else if (DETAIL ("hscale") || DETAIL ("vscale"))
-	{
-		WidgetParameters params;
-		SliderParameters slider;
-		
-		clearlooks_set_widget_parameters (widget, style, state_type, &params);
-		
-		slider.horizontal = DETAIL ("hscale");
-		
-		if (clearlooks_style->style == CL_STYLE_GLOSSY) /* XXX! */
-			params.corners = CR_CORNER_ALL;
-		
-		STYLE_FUNCTION(draw_slider_button) (cr, &clearlooks_style->colors,
-		                               &params, &slider,
-		                               x, y, width, height);
-	}
 	else if (DETAIL ("optionmenu"))
 	{
 		WidgetParameters params;
@@ -730,28 +689,22 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		
 		if (widget && GE_IS_MENU_BAR (widget->parent))
 		{
-			/*params.corners = CR_CORNER_NONE;
-			params.active = TRUE;
-			params.state_type = CL_STATE_ACTIVE;
-			params.xthickness = 2;
-			params.ythickness = 2;
-			
-			clearlooks_draw_button (cr, colors, &params, x, y, width, height+1);*/
-			
 			params.corners = CR_CORNER_TOPLEFT | CR_CORNER_TOPRIGHT;
 			height += 1;
+			STYLE_FUNCTION(draw_menubaritem) (cr, colors, &params, x, y, width, height);
 		}
 		else
 		{	
 			params.corners = CR_CORNER_ALL;
+			STYLE_FUNCTION(draw_menuitem) (cr, colors, &params, x, y, width, height);
 		}
-		
-		STYLE_FUNCTION(draw_menuitem) (cr, colors, &params, x, y, width, height);
 	}
-	else if (DETAIL ("hscrollbar") || DETAIL ("vscrollbar") || DETAIL ("slider") || DETAIL ("stepper"))
+	else if (DETAIL ("hscrollbar") || DETAIL ("vscrollbar")) /* This can't be "stepper" for scrollbars ... */
 	{
 		WidgetParameters    params;
 		ScrollBarParameters scrollbar;
+		ScrollBarStepperParameters stepper;
+		GdkRectangle this_rectangle = { x, y, width, height };
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 		params.corners = CR_CORNER_NONE;
@@ -759,11 +712,82 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		scrollbar.has_color  = FALSE;
 		scrollbar.horizontal = TRUE;
 		scrollbar.junction   = clearlooks_scrollbar_get_junction (widget);
-		scrollbar.steppers   = clearlooks_scrollbar_visible_steppers (widget);
 		
-		if (GE_IS_RANGE (widget))
-			scrollbar.horizontal = GTK_RANGE (widget)->orientation == GTK_ORIENTATION_HORIZONTAL;
+		scrollbar.horizontal = DETAIL ("hscrollbar");
 		
+		stepper.stepper = clearlooks_scrollbar_get_stepper (widget, &this_rectangle);
+
+		STYLE_FUNCTION(draw_scrollbar_stepper) (cr, colors, &params, &scrollbar, &stepper,
+			                                x, y, width, height);
+	}
+	else if (DETAIL ("toolbar") || DETAIL ("handlebox_bin") || DETAIL ("dockitem_bin"))
+	{
+		/* Only draw the shadows on horizontal toolbars */
+		if (shadow_type != GTK_SHADOW_NONE && height < 2*width )
+			STYLE_FUNCTION(draw_toolbar) (cr, colors, NULL, x, y, width, height);
+	}
+	else if (DETAIL ("trough"))
+	{
+			
+	}
+	else if (DETAIL ("menu"))
+	{
+		WidgetParameters params;
+		
+		clearlooks_set_widget_parameters (widget, style, state_type, &params);
+		
+		STYLE_FUNCTION(draw_menu_frame) (cr, colors, &params, x, y, width, height);
+	}
+	else
+	{
+		clearlooks_parent_class->draw_box (style, window, state_type, shadow_type, area,
+		                        widget, detail, x, y, width, height);
+	}
+	
+	cairo_destroy (cr);
+}
+
+static void
+clearlooks_style_draw_slider (DRAW_ARGS, GtkOrientation orientation)
+{
+	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
+	const ClearlooksColors *colors;
+	cairo_t *cr;
+
+	cr     = ge_gdk_drawable_to_cairo (window, area);
+	colors = &clearlooks_style->colors;
+
+	CHECK_ARGS
+	SANITIZE_SIZE
+	
+	if (DETAIL ("hscale") || DETAIL ("vscale"))
+	{
+		WidgetParameters params;
+		SliderParameters slider;
+		
+		clearlooks_set_widget_parameters (widget, style, state_type, &params);
+		
+		slider.horizontal = (orientation == GTK_ORIENTATION_HORIZONTAL);
+		
+		if (clearlooks_style->style == CL_STYLE_GLOSSY) /* XXX! */
+			params.corners = CR_CORNER_ALL;
+		
+		STYLE_FUNCTION(draw_slider_button) (cr, &clearlooks_style->colors,
+		                               &params, &slider,
+		                               x, y, width, height);
+	}
+	else if (DETAIL ("slider"))
+	{
+		WidgetParameters    params;
+		ScrollBarParameters scrollbar;
+
+		clearlooks_set_widget_parameters (widget, style, state_type, &params);
+		params.corners = CR_CORNER_NONE;
+
+		scrollbar.has_color  = FALSE;
+		scrollbar.horizontal = (orientation == GTK_ORIENTATION_HORIZONTAL);
+		scrollbar.junction   = clearlooks_scrollbar_get_junction (widget);
+
 		if (clearlooks_style->style == CL_STYLE_GLOSSY) /* XXX! */
 		{
 			scrollbar.color = colors->bg[CL_STATE_NORMAL];
@@ -776,66 +800,16 @@ clearlooks_style_draw_box (DRAW_ARGS)
 			scrollbar.has_color = TRUE;
 		}
 		
-		if (DETAIL ("slider"))
-		{
-			STYLE_FUNCTION(draw_scrollbar_slider) (cr, colors, &params, &scrollbar,
-			                                  x, y, width, height);
-		}
-		else
-		{
-			ScrollBarStepperParameters stepper;
-			GdkRectangle this_rectangle;
-			
-			this_rectangle.x = x;
-			this_rectangle.y = y;
-			this_rectangle.width = width;
-			this_rectangle.height = height;
-
-			stepper.stepper = clearlooks_scrollbar_get_stepper (widget, &this_rectangle);
-
-			STYLE_FUNCTION(draw_scrollbar_stepper) (cr, colors, &params, &scrollbar, &stepper,
-			                                   x, y, width, height);
-		}
-	}
-	else if (DETAIL ("toolbar") || DETAIL ("handlebox_bin") || DETAIL ("dockitem_bin"))
-	{
-		/* Only draw the shadows on horizontal toolbars */
-		if (shadow_type != GTK_SHADOW_NONE && height < 2*width )
-			STYLE_FUNCTION(draw_toolbar) (cr, colors, NULL, x, y, width, height);
-	}
-	else if (DETAIL ("trough"))
-	{
-		
-	}
-	else if (DETAIL ("menu"))
-	{
-		WidgetParameters params;
-		
-		clearlooks_set_widget_parameters (widget, style, state_type, &params);
-		
-		STYLE_FUNCTION(draw_menu_frame) (cr, colors, &params, x, y, width, height);
+		STYLE_FUNCTION(draw_scrollbar_slider) (cr, colors, &params, &scrollbar,
+		                                       x, y, width, height);
 	}
 	else
 	{
-		/* printf("draw_box: %s\n", detail); */
-		clearlooks_parent_class->draw_box (style, window, state_type, shadow_type, area,
-		                        widget, detail, x, y, width, height);
-	}
-	
-	cairo_destroy (cr);
-}
-
-static void
-clearlooks_style_draw_slider (DRAW_ARGS, GtkOrientation orientation)
-{
-	if (DETAIL ("hscale") || DETAIL ("vscale"))
-	{
-		clearlooks_style_draw_box (style, window, state_type, shadow_type, area,
-		          widget, detail, x, y, width, height);
-	}
-	else
 		clearlooks_parent_class->draw_slider (style, window, state_type, shadow_type, area,
 		                           widget, detail, x, y, width, height, orientation);
+	}
+
+	cairo_destroy (cr);
 }
 
 static void
@@ -843,13 +817,13 @@ clearlooks_style_draw_option (DRAW_ARGS)
 {
 	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
 	const ClearlooksColors *colors;
+	WidgetParameters params;
+	CheckboxParameters checkbox;
+	
 	cairo_t *cr;
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	colors = &clearlooks_style->colors;
 	
-	WidgetParameters params;
-	CheckboxParameters checkbox;
-	
 	checkbox.shadow_type = shadow_type;
 	checkbox.in_menu = (widget && GTK_IS_MENU(widget->parent));
 		
@@ -864,13 +838,13 @@ static void
 clearlooks_style_draw_check (DRAW_ARGS)
 {
 	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
+	WidgetParameters params;
+	CheckboxParameters checkbox;
+		
 
 	cairo_t *cr;
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
-	WidgetParameters params;
-	CheckboxParameters checkbox;
-		
 	clearlooks_set_widget_parameters (widget, style, state_type, &params);
 	
 	params.corners = CR_CORNER_ALL;
@@ -886,35 +860,6 @@ clearlooks_style_draw_check (DRAW_ARGS)
 	cairo_destroy (cr);
 }
 
-static void
-clearlooks_style_draw_tab (DRAW_ARGS)
-{
-	GtkRequisition indicator_size;
-	GtkBorder indicator_spacing;
-	gint arrow_height;
-
-	ge_option_menu_get_props (widget, &indicator_size, &indicator_spacing);
-	
-	indicator_size.width += (indicator_size.width % 2) - 1;
-	arrow_height = indicator_size.width / 2;
-	
-	x += (width - indicator_size.width) / 2;
-	y += height/2;
-
-
-	gtk_paint_arrow (style, window,
-	                 state_type, shadow_type,
-	                 area, widget, "arrow",
-	                 GTK_ARROW_UP, TRUE,
-	                 x, y-arrow_height-1, indicator_size.width, arrow_height);
-	                 
-	gtk_paint_arrow (style, window,
-	                 state_type, shadow_type,
-	                 area, widget, "arrow",
-	                 GTK_ARROW_DOWN, TRUE,
-	                 x, y+2, indicator_size.width, arrow_height);
-}
-
 static void
 clearlooks_style_draw_vline                      (GtkStyle               *style,
                                  GdkWindow              *window,
@@ -926,12 +871,17 @@ clearlooks_style_draw_vline                      (GtkStyle               *style,
                                  gint                    y2,
                                  gint                    x)
 {
+	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
+	const ClearlooksColors *colors;
 	SeparatorParameters separator = { FALSE };
 	cairo_t *cr;
 
+	colors = &clearlooks_style->colors;
+
+
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
-	STYLE_FUNCTION(draw_separator) (cr, NULL, NULL, &separator,
+	STYLE_FUNCTION(draw_separator) (cr, colors, NULL, &separator,
 	                           x, y1, 2, y2-y1);
 	
 	cairo_destroy (cr);
@@ -948,14 +898,18 @@ clearlooks_style_draw_hline                      (GtkStyle               *style,
                                  gint                    x2,
                                  gint                    y)
 {
+	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
+	const ClearlooksColors *colors;
 	cairo_t *cr;
 	SeparatorParameters separator;
-	
+
+	colors = &clearlooks_style->colors;
+
 	cr = ge_gdk_drawable_to_cairo (window, area);
 	
 	separator.horizontal = TRUE;
 	
-	STYLE_FUNCTION(draw_separator) (cr, NULL, NULL, &separator,
+	STYLE_FUNCTION(draw_separator) (cr, colors, NULL, &separator,
 	                           x1, y, x2-x1, 2);
 	
 	cairo_destroy (cr);
@@ -1041,6 +995,25 @@ clearlooks_style_draw_resize_grip (GtkStyle       *style,
 	return;
 }
 
+static void
+clearlooks_style_draw_tab (DRAW_ARGS)
+{
+	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
+	ClearlooksColors *colors = &clearlooks_style->colors;
+	WidgetParameters params;
+	ArrowParameters  arrow; 	 
+
+	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+
+	clearlooks_set_widget_parameters (widget, style, state_type, &params);
+	arrow.type      = CL_ARROW_COMBO;
+	arrow.direction = CL_DIRECTION_DOWN; 	 
+
+	STYLE_FUNCTION(draw_arrow) (cr, colors, &params, &arrow, x, y, width, height);
+
+	cairo_destroy (cr);
+}
+
 static void
 clearlooks_style_draw_arrow (GtkStyle  *style,
                        GdkWindow     *window,
@@ -1056,33 +1029,44 @@ clearlooks_style_draw_arrow (GtkStyle  *style,
                        gint           width,
                        gint           height)
 {
-	if (DETAIL ("arrow") && ge_is_combo_box (widget, FALSE) && !ge_is_combo_box_entry(widget))
+	ClearlooksStyle  *clearlooks_style = CLEARLOOKS_STYLE (style);
+	ClearlooksColors *colors = &clearlooks_style->colors;
+	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+		
+	SANITIZE_SIZE
+
+  if (arrow_type == (GtkArrowType)4) { /* NONE - new in GTK 2.10 */
+		cairo_destroy (cr);
+		return;
+	}
+
+	if (DETAIL ("arrow"))
 	{
-#define CL_COMBO_BOX_ARROW_WIDTH 8
-#define CL_COMBO_BOX_ARROW_HEIGHT 5
-
-		x += (width - CL_COMBO_BOX_ARROW_WIDTH) + 1;
-		y += 1;
+		WidgetParameters params;
+		ArrowParameters  arrow;
 		
-		width  = CL_COMBO_BOX_ARROW_WIDTH;
-		height = CL_COMBO_BOX_ARROW_HEIGHT;
+		clearlooks_set_widget_parameters (widget, style, state_type, &params);
+		arrow.type = CL_ARROW_NORMAL;
+		arrow.direction = (ClearlooksDirection)arrow_type;
+			
+    if (ge_is_combo_box (widget, FALSE) && !ge_is_combo_box_entry (widget)) 	 
+    { 	 
+            arrow.type = CL_ARROW_COMBO; 	 
+            y -= 2; 	 
+            height += 4; 	 
+            x += 1; 	 
+    }
 		
-		clearlooks_parent_class->draw_arrow (style, window, state_type, shadow, area,
-		                          widget, detail, GTK_ARROW_UP, fill,
-		                          x, y-1, width, height);
-
-		clearlooks_parent_class->draw_arrow (style, window, state_type, shadow, area,
-		                          widget, detail, GTK_ARROW_DOWN, fill,
-		                          x, y+height, width, height);
+		STYLE_FUNCTION(draw_arrow) (cr, colors, &params, &arrow, x, y, width, height);
 	}
 	else
 	{
-		/* printf("draw_arrow: %s %s\n", detail, widget ? G_OBJECT_TYPE_NAME (widget) : "null"); */
-
 		clearlooks_parent_class->draw_arrow (style, window, state_type, shadow, area,
 		                          widget, detail, arrow_type, fill,
 		                          x, y, width, height);
 	}
+	
+	cairo_destroy (cr);
 }
 
 static void
@@ -1096,13 +1080,11 @@ clearlooks_style_init_from_rc (GtkStyle * style,
 	g_assert ((CLEARLOOKS_RC_STYLE (rc_style)->style >= 0) && (CLEARLOOKS_RC_STYLE (rc_style)->style < CL_NUM_STYLES));
 	clearlooks_style->style		= CLEARLOOKS_RC_STYLE (rc_style)->style;
 	
-	clearlooks_style->progressbarstyle  = CLEARLOOKS_RC_STYLE (rc_style)->progressbarstyle;
 	clearlooks_style->menubarstyle      = CLEARLOOKS_RC_STYLE (rc_style)->menubarstyle;
-	clearlooks_style->menuitemstyle     = CLEARLOOKS_RC_STYLE (rc_style)->menuitemstyle;
-	clearlooks_style->listviewitemstyle = CLEARLOOKS_RC_STYLE (rc_style)->listviewitemstyle;
 	clearlooks_style->has_scrollbar_color = CLEARLOOKS_RC_STYLE (rc_style)->flags & CL_FLAG_SCROLLBAR_COLOR;
 	clearlooks_style->animation         = CLEARLOOKS_RC_STYLE (rc_style)->animation;
-	
+	clearlooks_style->radius            = CLAMP (CLEARLOOKS_RC_STYLE (rc_style)->radius, 0.0, 10.0);
+
 	if (clearlooks_style->has_scrollbar_color)
 		clearlooks_style->scrollbar_color = CLEARLOOKS_RC_STYLE (rc_style)->scrollbar_color;
 }
@@ -1111,7 +1093,7 @@ static void
 clearlooks_style_realize (GtkStyle * style)
 {
 	ClearlooksStyle *clearlooks_style = CLEARLOOKS_STYLE (style);
-	double shades[] = {1.15, 0.95, 0.896, 0.82, 0.7, 0.665, 0.5, 0.45, 0.4};
+	double shades[] = {1.15, 0.95, 0.896, 0.82, 0.7, 0.665, 0.475, 0.45, 0.4};
 	CairoColor spot_color;
 	CairoColor bg_normal;
 	double contrast;
@@ -1252,13 +1234,11 @@ clearlooks_style_copy (GtkStyle * style, GtkStyle * src)
 	ClearlooksStyle * cl_src = CLEARLOOKS_STYLE (src);
 	
 	cl_style->colors              = cl_src->colors;
-	cl_style->progressbarstyle    = cl_src->progressbarstyle;
 	cl_style->menubarstyle        = cl_src->menubarstyle;
-	cl_style->menuitemstyle       = cl_src->menuitemstyle;
-	cl_style->listviewitemstyle   = cl_src->listviewitemstyle;
 	cl_style->scrollbar_color     = cl_src->scrollbar_color;
 	cl_style->has_scrollbar_color = cl_src->has_scrollbar_color;
 	cl_style->animation           = cl_src->animation;
+	cl_style->radius              = cl_src->radius;
 	
 	clearlooks_parent_class->copy (style, src);
 }
@@ -1374,16 +1354,6 @@ clearlooks_style_draw_render_icon (GtkStyle            *style,
 	if (gtk_icon_source_get_state_wildcarded (source)) {
 		if (state == GTK_STATE_INSENSITIVE) {
 			stated = set_transparency (scaled, 0.3);
-#if 0
-			stated =
-				gdk_pixbuf_composite_color_simple (scaled,
-								   gdk_pixbuf_get_width (scaled),
-								   gdk_pixbuf_get_height (scaled),
-								   GDK_INTERP_BILINEAR, 128,
-								   gdk_pixbuf_get_width (scaled),
-								   style->bg[state].pixel,
-								   style->bg[state].pixel);
-#endif
 			gdk_pixbuf_saturate_and_pixelate (stated, stated,
 							  0.1, FALSE);
 			
@@ -1433,16 +1403,18 @@ clearlooks_style_class_init (ClearlooksStyleClass * klass)
 	style_class->draw_option      = clearlooks_style_draw_option;
 	style_class->draw_check       = clearlooks_style_draw_check;
 	style_class->draw_flat_box    = clearlooks_style_draw_flat_box;
-	style_class->draw_tab         = clearlooks_style_draw_tab;
 	style_class->draw_vline       = clearlooks_style_draw_vline;
 	style_class->draw_hline       = clearlooks_style_draw_hline;
 	style_class->draw_resize_grip = clearlooks_style_draw_resize_grip;
+	style_class->draw_tab         = clearlooks_style_draw_tab;
 	style_class->draw_arrow       = clearlooks_style_draw_arrow;
 	style_class->render_icon      = clearlooks_style_draw_render_icon;
 
 	clearlooks_register_style_classic (&clearlooks_style_class->style_functions[CL_STYLE_CLASSIC]);
 	clearlooks_style_class->style_functions[CL_STYLE_GLOSSY] = clearlooks_style_class->style_functions[CL_STYLE_CLASSIC];
 	clearlooks_register_style_glossy (&clearlooks_style_class->style_functions[CL_STYLE_GLOSSY]);
+	clearlooks_style_class->style_functions[CL_STYLE_INVERTED] = clearlooks_style_class->style_functions[CL_STYLE_CLASSIC];
+	clearlooks_register_style_inverted (&clearlooks_style_class->style_functions[CL_STYLE_INVERTED]);
 }
 
 GType clearlooks_type_style = 0;
